<a id="mypy-boto3-athena"></a>

# mypy-boto3-athena

[![PyPI - types-aiobotocore-athena](https://img.shields.io/pypi/v/types-aiobotocore-athena.svg?color=blue)](https://pypi.org/project/types-aiobotocore-athena)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-athena.svg?color=blue)](https://pypi.org/project/types-aiobotocore-athena)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-athena?color=blue)](https://pypistats.org/packages/types-aiobotocore-athena)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.Athena 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/athena.html#Athena)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-athena docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_athena/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-athena](#mypy-boto3-athena)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `Athena`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `Athena` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[athena]'

# Lite version does not provide session.create_client overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[athena]'

# standalone installation
python -m pip install types-aiobotocore-athena
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[athena]` in your environment:
  `python -m pip install 'types-aiobotocore[athena]'`

Both type checking and auto-complete should work for `Athena` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[athena]` in your environment:
  `python -m pip install 'types-aiobotocore[athena]'`

Both type checking and auto-complete should work for `Athena` service. No
explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[athena]` in your environment:
  `python -m pip install 'types-aiobotocore[athena]'`
- Run `mypy` as usual

Type checking should work for `Athena` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[athena]` in your environment:
  `python -m pip install 'types-aiobotocore[athena]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Athena` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`AthenaClient` provides annotations for `session.create_client("athena")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_athena import AthenaClient

session = get_session()
async with session.create_client("athena") as client:
    client: AthenaClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_athena.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_athena import AthenaClient
from types_aiobotocore_athena.paginator import (
    GetQueryResultsPaginator,
    ListDataCatalogsPaginator,
    ListDatabasesPaginator,
    ListNamedQueriesPaginator,
    ListQueryExecutionsPaginator,
    ListTableMetadataPaginator,
    ListTagsForResourcePaginator,
)

session = get_session()
async with session.create_client("athena") as client:
    client: AthenaClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        get_query_results_paginator: GetQueryResultsPaginator = client.get_paginator("get_query_results")
        list_data_catalogs_paginator: ListDataCatalogsPaginator = client.get_paginator("list_data_catalogs")
        list_databases_paginator: ListDatabasesPaginator = client.get_paginator("list_databases")
        list_named_queries_paginator: ListNamedQueriesPaginator = client.get_paginator("list_named_queries")
        list_query_executions_paginator: ListQueryExecutionsPaginator = client.get_paginator("list_query_executions")
        list_table_metadata_paginator: ListTableMetadataPaginator = client.get_paginator("list_table_metadata")
        list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
    ```







### Literals

`types_aiobotocore_athena.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_athena.literals import (
    ColumnNullableType,
    DataCatalogTypeType,
    EncryptionOptionType,
    GetQueryResultsPaginatorName,
    ListDataCatalogsPaginatorName,
    ListDatabasesPaginatorName,
    ListNamedQueriesPaginatorName,
    ListQueryExecutionsPaginatorName,
    ListTableMetadataPaginatorName,
    ListTagsForResourcePaginatorName,
    QueryExecutionStateType,
    StatementTypeType,
    WorkGroupStateType,
    ServiceName,
    PaginatorName,
)

def check_value(value: ColumnNullableType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_athena.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_athena.type_defs import (
    BatchGetNamedQueryInputRequestTypeDef,
    BatchGetNamedQueryOutputTypeDef,
    BatchGetQueryExecutionInputRequestTypeDef,
    BatchGetQueryExecutionOutputTypeDef,
    ColumnInfoTypeDef,
    ColumnTypeDef,
    CreateDataCatalogInputRequestTypeDef,
    CreateNamedQueryInputRequestTypeDef,
    CreateNamedQueryOutputTypeDef,
    CreatePreparedStatementInputRequestTypeDef,
    CreateWorkGroupInputRequestTypeDef,
    DataCatalogSummaryTypeDef,
    DataCatalogTypeDef,
    DatabaseTypeDef,
    DatumTypeDef,
    DeleteDataCatalogInputRequestTypeDef,
    DeleteNamedQueryInputRequestTypeDef,
    DeletePreparedStatementInputRequestTypeDef,
    DeleteWorkGroupInputRequestTypeDef,
    EncryptionConfigurationTypeDef,
    EngineVersionTypeDef,
    GetDataCatalogInputRequestTypeDef,
    GetDataCatalogOutputTypeDef,
    GetDatabaseInputRequestTypeDef,
    GetDatabaseOutputTypeDef,
    GetNamedQueryInputRequestTypeDef,
    GetNamedQueryOutputTypeDef,
    GetPreparedStatementInputRequestTypeDef,
    GetPreparedStatementOutputTypeDef,
    GetQueryExecutionInputRequestTypeDef,
    GetQueryExecutionOutputTypeDef,
    GetQueryResultsInputRequestTypeDef,
    GetQueryResultsOutputTypeDef,
    GetTableMetadataInputRequestTypeDef,
    GetTableMetadataOutputTypeDef,
    GetWorkGroupInputRequestTypeDef,
    GetWorkGroupOutputTypeDef,
    ListDataCatalogsInputRequestTypeDef,
    ListDataCatalogsOutputTypeDef,
    ListDatabasesInputRequestTypeDef,
    ListDatabasesOutputTypeDef,
    ListEngineVersionsInputRequestTypeDef,
    ListEngineVersionsOutputTypeDef,
    ListNamedQueriesInputRequestTypeDef,
    ListNamedQueriesOutputTypeDef,
    ListPreparedStatementsInputRequestTypeDef,
    ListPreparedStatementsOutputTypeDef,
    ListQueryExecutionsInputRequestTypeDef,
    ListQueryExecutionsOutputTypeDef,
    ListTableMetadataInputRequestTypeDef,
    ListTableMetadataOutputTypeDef,
    ListTagsForResourceInputRequestTypeDef,
    ListTagsForResourceOutputTypeDef,
    ListWorkGroupsInputRequestTypeDef,
    ListWorkGroupsOutputTypeDef,
    NamedQueryTypeDef,
    PaginatorConfigTypeDef,
    PreparedStatementSummaryTypeDef,
    PreparedStatementTypeDef,
    QueryExecutionContextTypeDef,
    QueryExecutionStatisticsTypeDef,
    QueryExecutionStatusTypeDef,
    QueryExecutionTypeDef,
    ResponseMetadataTypeDef,
    ResultConfigurationTypeDef,
    ResultConfigurationUpdatesTypeDef,
    ResultSetMetadataTypeDef,
    ResultSetTypeDef,
    RowTypeDef,
    StartQueryExecutionInputRequestTypeDef,
    StartQueryExecutionOutputTypeDef,
    StopQueryExecutionInputRequestTypeDef,
    TableMetadataTypeDef,
    TagResourceInputRequestTypeDef,
    TagTypeDef,
    UnprocessedNamedQueryIdTypeDef,
    UnprocessedQueryExecutionIdTypeDef,
    UntagResourceInputRequestTypeDef,
    UpdateDataCatalogInputRequestTypeDef,
    UpdatePreparedStatementInputRequestTypeDef,
    UpdateWorkGroupInputRequestTypeDef,
    WorkGroupConfigurationTypeDef,
    WorkGroupConfigurationUpdatesTypeDef,
    WorkGroupSummaryTypeDef,
    WorkGroupTypeDef,
)

def get_structure() -> BatchGetNamedQueryInputRequestTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-athena` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-athena docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_athena/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
